==> adsmanager-facade-2.1.1-sources.jar: com/bxm/adsmanager/facade/model/ticket/AdTicketCostLog.java <==
package com.bxm.adsmanager.facade.model.ticket;

import java.io.Serializable;
import java.util.Date;

public class AdTicketCostLog implements Serializable {
    private static final long serialVersionUID = 2211569501126724258L;
    private Long id;
    //券id
    private Long ticketId;

    private String putId;

    //素材
    private String assetIds;

    //标签
    private String tag;

    //券状态
    private String ticketStatus;

    //提醒值
    private String cosWarn;

    private String need;
    //券消耗
    private Double cost;

    //缓存中的券消耗
    private Double costRds;

    private Date createTime;
    private String outsideUrl;

    private Date deleteTime;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getTicketId() {
        return ticketId;
    }

    public void setTicketId(Long ticketId) {
        this.ticketId = ticketId;
    }

    public String getAssetIds() {
        return assetIds;
    }

    public void setAssetIds(String assetIds) {
        this.assetIds = assetIds == null ? null : assetIds.trim();
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag == null ? null : tag.trim();
    }

    public String getTicketStatus() {
        return ticketStatus;
    }

    public void setTicketStatus(String ticketStatus) {
        this.ticketStatus = ticketStatus == null ? null : ticketStatus.trim();
    }

    public String getCosWarn() {
        return cosWarn;
    }

    public void setCosWarn(String cosWarn) {
        this.cosWarn = cosWarn == null ? null : cosWarn.trim();
    }

    public Double getCost() {
        return cost;
    }

    public void setCost(Double cost) {
        this.cost = cost;
    }

    public Double getCostRds() {
        return costRds;
    }

    public void setCostRds(Double costRds) {
        this.costRds = costRds;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getOutsideUrl() {
        return outsideUrl;
    }

    public void setOutsideUrl(String outsideUrl) {
        this.outsideUrl = outsideUrl;
    }

    public Date getDeleteTime() {
        return deleteTime;
    }

    public void setDeleteTime(Date deleteTime) {
        this.deleteTime = deleteTime;
    }

    public String getPutId() {
        return putId;
    }

    public void setPutId(String putId) {
        this.putId = putId;
    }

    public String getNeed() {
        return need;
    }

    public void setNeed(String need) {
        this.need = need;
    }
}

==> adsmanager-facade-3.3.3-sources.jar: com/bxm/adsmanager/facade/model/ticket/AdTicketCostLog.java <==
package com.bxm.adsmanager.facade.model.ticket;

import java.io.Serializable;
import java.util.Date;

public class AdTicketCostLog implements Serializable {
    private static final long serialVersionUID = 2211569501126724258L;
    private Long id;
    //券id
    private Long ticketId;

    private String putId;

    //素材
    private String assetIds;

    //标签
    private String tag;

    //券状态
    private String ticketStatus;

    //提醒值
    private String cosWarn;

    private String need;
    //券消耗
    private Double cost;

    //缓存中的券消耗
    private Double costRds;

    private Date createTime;
    private String outsideUrl;

    private Date deleteTime;

    private String positionId;

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getTicketId() {
        return ticketId;
    }

    public void setTicketId(Long ticketId) {
        this.ticketId = ticketId;
    }

    public String getAssetIds() {
        return assetIds;
    }

    public void setAssetIds(String assetIds) {
        this.assetIds = assetIds == null ? null : assetIds.trim();
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag == null ? null : tag.trim();
    }

    public String getTicketStatus() {
        return ticketStatus;
    }

    public void setTicketStatus(String ticketStatus) {
        this.ticketStatus = ticketStatus == null ? null : ticketStatus.trim();
    }

    public String getCosWarn() {
        return cosWarn;
    }

    public void setCosWarn(String cosWarn) {
        this.cosWarn = cosWarn == null ? null : cosWarn.trim();
    }

    public Double getCost() {
        return cost;
    }

    public void setCost(Double cost) {
        this.cost = cost;
    }

    public Double getCostRds() {
        return costRds;
    }

    public void setCostRds(Double costRds) {
        this.costRds = costRds;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getOutsideUrl() {
        return outsideUrl;
    }

    public void setOutsideUrl(String outsideUrl) {
        this.outsideUrl = outsideUrl;
    }

    public Date getDeleteTime() {
        return deleteTime;
    }

    public void setDeleteTime(Date deleteTime) {
        this.deleteTime = deleteTime;
    }

    public String getPutId() {
        return putId;
    }

    public void setPutId(String putId) {
        this.putId = putId;
    }

    public String getNeed() {
        return need;
    }

    public void setNeed(String need) {
        this.need = need;
    }
}
